Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(605)

Unified Diff: third_party/WebKit/Source/platform/graphics/GraphicsContextState.h

Issue 2523673004: [NOT FOR COMMIT] Fully replace SkCanvas uses.
Patch Set: Support Android build. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/GraphicsContextState.h
diff --git a/third_party/WebKit/Source/platform/graphics/GraphicsContextState.h b/third_party/WebKit/Source/platform/graphics/GraphicsContextState.h
index 2f49b7a398cb715f29ffb633392f60edd2df540c..f2551beff19a56ae1fc28e25a70bde1da830633d 100644
--- a/third_party/WebKit/Source/platform/graphics/GraphicsContextState.h
+++ b/third_party/WebKit/Source/platform/graphics/GraphicsContextState.h
@@ -32,6 +32,7 @@
#include "platform/graphics/DrawLooperBuilder.h"
#include "platform/graphics/GraphicsTypes.h"
#include "platform/graphics/StrokeData.h"
+#include "skia/ext/cdl_paint.h"
#include "third_party/skia/include/core/SkColorFilter.h"
#include "third_party/skia/include/core/SkPaint.h"
#include "third_party/skia/include/core/SkRefCnt.h"
@@ -59,10 +60,10 @@ class PLATFORM_EXPORT GraphicsContextState final {
void copy(const GraphicsContextState&);
// SkPaint objects that reflect the current state. If the length of the
// path to be stroked is known, pass it in for correct dash or dot placement.
- const SkPaint& strokePaint(int strokedPathLength = 0) const;
- const SkPaint& fillPaint() const { return m_fillPaint; }
+ const CdlPaint& strokePaint(int strokedPathLength = 0) const;
+ const CdlPaint& fillPaint() const { return m_fillPaint; }
uint16_t saveCount() const { return m_saveCount; }
void incrementSaveCount() { ++m_saveCount; }
@@ -119,8 +120,8 @@ class PLATFORM_EXPORT GraphicsContextState final {
// This is mutable to enable dash path effect updates when the paint is
// fetched for use.
- mutable SkPaint m_strokePaint;
- SkPaint m_fillPaint;
+ mutable CdlPaint m_strokePaint;
+ CdlPaint m_fillPaint;
StrokeData m_strokeData;

Powered by Google App Engine
@@ -59,10 +60,10 @@ class PLATFORM_EXPORT GraphicsContextState final {
void copy(const GraphicsContextState&);
- // SkPaint objects that reflect the current state. If the length of the
+ // CdlPaint objects that reflect the current state. If the length of the
// path to be stroked is known, pass it in for correct dash or dot placement.
This is Rietveld 408576698